<?php

namespace Andy\ForumListCount\XF\Pub\Controller;

use XF\Mvc\ParameterBag;

class Forum extends XFCP_Forum
{
	public function actionList(ParameterBag $params)
	{
		//########################################
		// forum_list
		//########################################
		
		// get parent
		$parent = parent::actionList($params);

		// get visitor
		$visitor = \XF::visitor();
		
		// get userId
		$userId = $visitor['user_id'];	
		
		// get userAgent
		$userAgent = @$_SERVER['HTTP_USER_AGENT'];
		
		// set default timezone
		date_default_timezone_set('Europe/London');		
		
		// get date variables
		$year = date("Y", time());
		$month = date("m", time());	
		$day = date("d", time());	
		
		// get today
		$today = $year . $month . $day;

        // get data
        $finder = \XF::finder('Andy\ForumListCount:ForumListCount');
        $forumListCount = $finder
            ->where('count_date', $today)
            ->fetchOne();
		
		// check condition
		if (empty($forumListCount))
		{
            // save forumListCount
            $forumListCount = \XF::em()->create('Andy\ForumListCount:ForumListCount');
            $forumListCount->count_date = $today;
            $forumListCount->count_guest = 0;
            $forumListCount->count_member = 0;
            $forumListCount->count_robot = 0;
			try
			{
				$forumListCount->save();
			}
			catch (\XF\Db\DuplicateKeyException $e) {}
		}

		// check condition
		if (!empty($forumListCount))
		{
            // get options
            $options = \XF::options();	

            // get options from Admin CP -> Options -> Forum list count -> Robot names
            $robotNames = $options->forumListCountRobotNames;

            // get robotNamesArray
            $robotNamesArray = array();

            // check condition
            if (!empty($robotNames))
            {
                // remove line breaks
                $robotNames = preg_replace("/\r|\n/", "", $robotNames);

                // remove trailing comma
                $robotNames = rtrim($robotNames, ',');

                // make lowercase
                $robotNames = strtolower($robotNames);							

                // create robotNamesArray
                $robotNamesArray = explode(',', $robotNames);
            }

            // get robot
            $robot = false;

            // check condition
            if (preg_match('#(' . implode('|', array_map('preg_quote', $robotNamesArray)) . ')#i', strtolower($userAgent)))
            {
                $robot = true;
            }		

            // check condition
            if ($userId == 0 AND !$robot)
            {
                $countGuest = $forumListCount['count_guest'] + 1;
                
                $data = [
                    'count_guest' => $countGuest
                ];

                $forumListCount->fastUpdate($data);			
            }

            // check condition
            if ($userId > 0 AND !$robot)
            {
                $countMember = $forumListCount['count_member'] + 1;
                
                $data = [
                    'count_member' => $countMember
                ];                

                $forumListCount->fastUpdate($data);			
            }	

            // check condition
            if ($robot)
            {
                $countRobot = $forumListCount['count_robot'] + 1;
                
                $data = [
                    'count_robot' => $countRobot
                ];

                $forumListCount->fastUpdate($data);			
            }
        }
				
		// return parent
		return $parent;
	}
}